# ApiFlash Python Client

This is a placeholder for a future python ApiFlash [website screenshot API](https://apiflash.com) client. 
Get in touch with us at [contact@apiflash.com](mailto:contact@apiflash.com) if you need this client. 

## Installation

Signup at [apiflash.com](https://apiflash.com) to get your API key.

```
pip install apiflash
```

## Example

```python
# Python client not available yet.
```

## Parameters

Check the [ApiFlash documentation](https://apiflash.com/documentation) for more details.